@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
-from nose.tools import eq_
-
 from anytree import Node
-from anytree.util import commonancestors
-from anytree.util import leftsibling
-from anytree.util import rightsibling
+from anytree.util import commonancestors, leftsibling, rightsibling
+
+from .helper import eq_
 
 
 def test_commonancestors():
@@ -20,7 +18,7 @@ def test_commonancestors():
     eq_(commonancestors(jet, marc), (udo,))
     eq_(commonancestors(jet), (udo, dan))
     eq_(commonancestors(), ())
-    eq_(commonancestors(jet, lian), (udo, ))
+    eq_(commonancestors(jet, lian), (udo,))
 
 
 def test_leftsibling():
